##====================================================================##
##==Purpose: To get the boxplot of slopes, dominant trajectories and==##
##===        counts of up/down for the various gene sets            ==##
##==                                                                ==##
##==Input:                                                          ==##
##==  *data/Rdata/probesets.CanonicalPathway.Rdata                  ==##
##==  The R objects: pIds.mhc2, pIds.p38, pIds.tlr, pIds.il6,       ==##
##==  and pIds.top5, contain the probesets id associated with the   ==##
##==  each gene set.                                                ==##
##==  *txt.info                                                     ==##
##==  Specifying name of the *.txt file which contains the          ==##        
##==  microarrays id. For example, the microarrays for batch is in  ==##
##==  "microarrayID250.168.batch1.txt", then txt.info is            ==##
##==  "microarrayID250.168.batch"                                   ==##
##==  *type1                                                        ==##
##==  A string indicating the gene expression of interest           ==## 
##==  e.g.                                                          ==##
##==  txt.info<-"microarrayID250.168.batch"                         ==##
##==  min_hours<-12;                                                ==##
##==  max_hours<-250;                                               ==##
##==  type1<-paste(txt.info," Slope (",min_hours,"-",max_hours,")", ==##
##==  sep="")                                                       ==##
##==  *data/Rdata/settings.Rdata                                    ==##
##==  Contains R objects which are the settings, bypassnorm &       ==##
##==  pngPlot                                                       ==##  
##==  *Additional parameters                                        ==##
##==  -min_hours, e.g. 12                                           ==##
##==  -max_hours, e.g. 250                                          ==## 
##==  -type.fig, e.g. "main" (if figure is in the main paper)       ==##
##==  -can.name, e.g. "MHC2" (if the gene set of interest is MHC2)  ==##
##==   (others: "P38", "TLR", "IL6", "TOP5")                        ==##
##==  -pIds, e.g. pIds.mhc2 (these are the probesets corresponding  ==##
##==              MHC2, which is taken from                         ==##
##==              data/Rdata/probesets.CanonicalPathway.Rdata       ==##
##==   (others: pIds.p38, pIds.tlr, pIds.il6, pIds.top5             ==##
##==  -y.lim, the range of gene expression trajectories             ==##
##==  -y.axis, the ramge of boxplot of WPEC                         ==##
##==                                                                ==##
##==Sub-routines:                                                   ==##
##==  *Routines to generate plots for the paper                     ==##
##==  code/5_genesets/slope_trajectory_count.R              	    ==##
##==                                                                ==##
##==Figures for paper:                                              ==##
##==  plots/forpaper/Supplementary_Figure16_.png, 18, 20, 22 & 24   ==##
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu             ==##
##         kdesai@princeton.edu                                     ==##
##====================================================================##

##==========##
##==MHC-II==##
##==========##
txt.info<-"microarrayID250.168.batch"
min_hours<-12;
max_hours<-250;
type1<-paste(txt.info," Slope (",min_hours,"-",max_hours,")",sep="")

type.fig<-"main"
load(file="data/Rdata/probesets.CanonicalPathway.Rdata")
can.name<-"MHC2"
pIds<-pIds.mhc2
y.lim<-c(-0.9,0.7)
y.axis<-c(-5,0,5)

load(file="data/Rdata/settings.Rdata")

print("Plotting MHC2")
if(pngPlot){
  png(paste("plots/forpaper/Supplementary_Figure16_",can.name,".png",sep=""),width=5600,height=4400,res=300)
}else{
  pdf(paste("plots/forpaper/Supplementary_Figure16_",can.name,".pdf",sep=""),width=9*2,height=7*2,pointsize=12)
}
tmp<-rbind(cbind(0,matrix(c(rep(c(1:10),each=3),c(0,0,rep(11,4),0,0),c(rep(12,4),0,0,0)),
				 ncol=15,byrow=TRUE)),0)
tmp<-cbind(0,tmp)
nf<-layout(tmp, width=c(0.3,1,1,1,1,1,1),height=c(1,1,1,0.1),respect = FALSE)
								  
par(cex=1.5,cex.axis=1,cex.lab=1,cex.main=1,cex.sub=1)
source("code/5_genesets/slope_trajectory_count.R",local=TRUE)
dev.off()  
rm(list=ls())
print("End plotting MHC2")

##===========##
##==p38MAPK==##
##===========##
txt.info<-"microarrayID250.168.batch"
min_hours<-12;
max_hours<-250;
type1<-paste(txt.info," Slope (",min_hours,"-",max_hours,")",sep="")

type.fig<-"main"
load(file="data/Rdata/probesets.CanonicalPathway.Rdata")
can.name<-"P38"
pIds<-pIds.p38
y.lim<-c(-0.8,0.4)
y.axis<-c(-9,-6,-3,0,3)

load(file="data/Rdata/settings.Rdata")

print("Plotting P38")
if(pngPlot){
	png(paste("plots/forpaper/Supplementary_Figure18_",can.name,".png",sep=""),width=5600,height=4400,res=300)
}else{
	pdf(paste("plots/forpaper/Supplementary_Figure18_",can.name,".pdf",sep=""),width=9*2,height=7*2,pointsize=12)
}


tmp<-rbind(cbind(0,matrix(c(rep(c(1:10),each=3),c(0,0,rep(11,4),0,0),c(rep(12,4),0,0,0)),
                 ncol=15,byrow=TRUE)),0)
tmp<-cbind(0,tmp)
nf<-layout(tmp, width=c(0.3,1,1,1,1,1,1),height=c(1,1,1,0.1),respect = FALSE)

par(cex=1.5,cex.axis=1,cex.lab=1,cex.main=1,cex.sub=1)
source("code/5_genesets/slope_trajectory_count.R",local=TRUE)
dev.off()
rm(list=ls())
print("End plotting P38")

##=======##
##==TLR==##
##=======##
txt.info<-"microarrayID250.168.batch"
min_hours<-12;
max_hours<-250;
type1<-paste(txt.info," Slope (",min_hours,"-",max_hours,")",sep="")

type.fig<-"main"
load(file="data/Rdata/probesets.CanonicalPathway.Rdata")
can.name<-"TLR"
pIds<-pIds.tlr
y.lim<-c(-0.9,0.4)
y.axis<-c(-9,-6,-3,0,3)

load(file="data/Rdata/settings.Rdata")

print("Plotting TLR")
if(pngPlot){
	png(paste("plots/forpaper/Supplementary_Figure20_",can.name,".png",sep=""),width=5600,height=4400,res=300)
}else{
	pdf(paste("plots/forpaper/Supplementary_Figure20_",can.name,".pdf",sep=""),width=9*2,height=7*2,pointsize=12)
}

tmp<-rbind(cbind(0,matrix(c(rep(c(1:10),each=3),c(0,0,rep(11,4),0,0),c(rep(12,4),0,0,0)),
                 ncol=15,byrow=TRUE)),0)
tmp<-cbind(0,tmp)
nf<-layout(tmp, width=c(0.3,1,1,1,1,1,1),height=c(1,1,1,0.1),respect = FALSE)

par(cex=1.5,cex.axis=1,cex.lab=1,cex.main=1,cex.sub=1)
source("code/5_genesets/slope_trajectory_count.R",local=TRUE)
dev.off()
rm(list=ls())
print("End plotting TLR")


##=======##
##==IL6==##
##=======##
txt.info<-"microarrayID250.168.batch"
min_hours<-12;
max_hours<-250;
type1<-paste(txt.info," Slope (",min_hours,"-",max_hours,")",sep="")

type.fig<-"main"
load(file="data/Rdata/probesets.CanonicalPathway.Rdata")
can.name<-"IL6"
pIds<-pIds.il6
y.lim<-c(-0.9,0.4)
y.axis<-c(-9,-6,-3,0,3)

load(file="data/Rdata/settings.Rdata")

print("Plotting IL6")
if(pngPlot){
	png(paste("plots/forpaper/Supplementary_Figure22_",can.name,".png",sep=""),width=5600,height=4400,res=300)
}else{
	pdf(paste("plots/forpaper/Supplementary_Figure22_",can.name,".pdf",sep=""),width=9*2,height=7*2,pointsize=12)
}


tmp<-rbind(cbind(0,matrix(c(rep(c(1:10),each=3),c(0,0,rep(11,4),0,0),c(rep(12,4),0,0,0)),
                 ncol=15,byrow=TRUE)),0)
tmp<-cbind(0,tmp)
nf<-layout(tmp, width=c(0.3,1,1,1,1,1,1),height=c(1,1,1,0.1),respect = FALSE)

par(cex=1.5,cex.axis=1,cex.lab=1,cex.main=1,cex.sub=1)
source("code/5_genesets/slope_trajectory_count.R",local=TRUE)
dev.off()
rm(list=ls())
print("End plotting IL6")


##========##
##==TOP5==##
##========##
txt.info<-"microarrayID250.168.batch"
min_hours<-12;
max_hours<-250;
type1<-paste(txt.info," Slope (",min_hours,"-",max_hours,")",sep="")

type.fig<-"main"
load(file="data/Rdata/probesets.CanonicalPathway.Rdata")
can.name<-"TOP5"
pIds<-pIds.top5
y.lim<-c(-0.4,0.2)
y.axis<-c(-2.5,0,2.5)

load(file="data/Rdata/settings.Rdata")

print("Plotting Production of nitric oxide and reactive oxygen species in macrophages, and Antigen presentation")
if(pngPlot){
	png(paste("plots/forpaper/Supplementary_Figure24_",can.name,".png",sep=""),width=5600,height=4400,res=300)
}else{
	pdf(paste("plots/forpaper/Supplementary_Figure24_",can.name,".pdf",sep=""),width=9*2,height=7*2,pointsize=12)
}

tmp<-rbind(cbind(0,matrix(c(rep(c(1:10),each=3),c(0,0,rep(11,4),0,0),c(rep(12,4),0,0,0)),
                 ncol=15,byrow=TRUE)),0)
tmp<-cbind(0,tmp)
nf<-layout(tmp, width=c(0.3,1,1,1,1,1,1),height=c(1,1,1,0.1),respect = FALSE)

par(cex=1.5,cex.axis=1,cex.lab=1,cex.main=1,cex.sub=1)
source("code/5_genesets/slope_trajectory_count.R",local=TRUE)
dev.off()
rm(list=ls())
print("End plotting Production of nitric oxide and reactive oxygen species in macrophages, and Antigen presentation")
