##====================================================================##
##==Purpose: Plot the mean log-expression of MHC-II and p38MAPK gene==##
##==         sets with endotoxin data                               ==##
##==                                                                ==##
##==Input:                                                          ==##
##==  *Endotoxin data:                                              ==##                       
##==  data/endotoxin/endotoxin.csv                                  ==##
##==  *Probesets associated with gene sets                          ==##
##==  data/Rdata/probesets.CanonicalPathway.Rdata                   ==##
##==                                                                ==##
##==Figures for supplementary appendix:                             ==##
##==  plots/forpaper/Supplementary_Figure25_endotoxin.pdf           ==##
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu/            ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##

##==============================##
##==Load the endotoxin dataset==##
##==============================##
expr<-read.csv("data/endotoxin/endotoxin.csv",
                skip=3,header=FALSE)
##The probesets ID
exprID<-as.character(expr[,1])
##The gene expression
expr<-as.matrix(expr[,-1])

##The clinical data
clin<-read.csv("data/endotoxin/endotoxin.csv",
               skip=0,nrows=3,as.is=TRUE,
               header=FALSE)

clin<-t(clin)
colnames(clin)<-clin[1,]
clin<-clin[-1,]
clin<-data.frame(class=as.factor(clin[,1]),
                 individual=as.numeric(clin[,2]),
                 time=as.numeric(clin[,3]))
rownames(clin)<-paste(clin[,2],clin[,3],sep=".")
colnames(expr)<-rownames(clin)

##Order the columns by class, individual then time
o<-order(clin[,1],clin[,2],clin[,3])
clin<-clin[o,]
expr<-expr[,o]

dat<-log2(expr+10)
colnames(dat)<-colnames(expr)
if(!all(colnames(expr)==rownames(clin))) stop("There is something wrong")
rm(expr)

##==Load the probesets of the canonical pathways
load(file="data/Rdata/probesets.CanonicalPathway.Rdata")

##==========================================##
##==Get the mean log-expression for MHC-II==##
##==========================================##

pIds<-pIds.mhc2
valid<-which(exprID%in%pIds)
time<-sort(unique(clin[,3]))
mDat<-NULL
count<-1
for(i in as.character(unique(clin[,1]))){
  print(i)
  col.id<-which(clin[,1]==i)
  m<-NULL
  for(t in time){
    m<-c(m,mean(dat[valid,col.id[clin[col.id,3]==t]]))
  }
  mDat<-cbind(mDat,m)
  colnames(mDat)[count]<-as.character(i)
  count<-count+1
}
rownames(mDat)<-time
mhc2.mDat<-mDat

##===========================================##
##==Get the mean log-expression for p38MAPK==##
##===========================================##
pIds<-pIds.p38
valid<-which(exprID%in%pIds)
time<-sort(unique(clin[,3]))
mDat<-NULL
count<-1
for(i in as.character(unique(clin[,1]))){
  print(i)
  col.id<-which(clin[,1]==i)
  m<-NULL
  for(t in time){
    m<-c(m,mean(dat[valid,col.id[clin[col.id,3]==t]]))
  }
  mDat<-cbind(mDat,m)
  colnames(mDat)[count]<-as.character(i)
  count<-count+1
}
rownames(mDat)<-time
p38.mDat<-mDat

##=======================================================##
##==Plot the mean lof-expression for MHC-II and p38MAPK==##
##=======================================================##
pdf("plots/forpaper/Supplementary_Figure25_endotoxin.pdf")
par(mfrow=c(2,1))
plot(0,xlim=range(time),ylim=range(mhc2.mDat),
    xlab="Hours",ylab="Mean of log-expression",
    main="")
for(i in 1:ncol(mhc2.mDat)){
  lines(time,mhc2.mDat[,i],col=i,lwd=2)
}
mtext("a",side=3,adj=0,font=2,cex=1.5)
plot(0,xlim=range(time),ylim=range(p38.mDat),
     xlab="Hours",ylab="Mean of log-expression",
     main="")
for(i in 1:ncol(p38.mDat)){
  lines(time,p38.mDat[,i],col=i,lwd=2)
}

mtext("b",side=3,adj=0,font=2,cex=1.5)
dev.off()
