##====================================================================##
##==Purpose: Identifying probests with similar WPEC profile as MHC2 ==##
##==         gene sets.                                             ==##
##==                                                                ==##
##==Input:                                                          ==##
##==  "data/Rdata/microarray/",type1,".Rdata"                       ==##
##==  "data/Rdata/probesets.CanonicalPathway.Rdata"                 ==##
##==                                                                ==##
##==Output:                                                         ==##
##==  "data/csv/top500_absolute_correlation_MHC2.csv"               ==##
##==  500 probeset with the highest absolute average correlation    ==##  
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu/            ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##


##==Assessing the variation in WPEC (i.e. slope matrix)
txt.info<-"microarrayID250.168.batch"
min_hours<-12
max_hours<-250
type1<-paste(txt.info," Slope (",min_hours,"-",max_hours,")",sep="")
##Get the microarray data
load(file=paste("data/Rdata/microarray/",type1,".Rdata",sep=""))
##Get the probesets of the gene sets
load(file="data/Rdata/probesets.CanonicalPathway.Rdata")


##Filter the microarray data
##Remove the individuals due to quality reasons and death status
gDat<-gDat[,!(as.numeric(colnames(gDat))%in%c(8028773,25993337,33426107))]

##Get the average correlation between MHC2 gene sets and the other probesets
##Retain those probesets with consistent sign
cor.gDat<-cor(t(gDat[rownames(gDat)%in%pIds.mhc2,]),t(gDat[!(rownames(gDat)%in%pIds.mhc2),]))
mcor.gDat<-colMeans(cor.gDat)
length(mcor.gDat)
mcor.gDat<-mcor.gDat[apply(sign(cor.gDat),2,function(x) length(unique(x))==1)]
length(mcor.gDat)

##Get the top 500 probesets
top500<-rev(order(abs(mcor.gDat)))[1:500]
p500<-names(mcor.gDat)[top500]
write.table(p500,file="data/csv/top500_absolute_correlation_MHC2.csv",sep=",")


