##====================================================================##
##==Purpose: Regresses the clinical variables onto the principal    ==##
##==         components of WPEC and mean expression                 ==##
##==                                                                ==##
##==Input:                                                          ==##
##==  "data/Rdata/microarray/",type1,".Rdata"                       ==##
##==                                                                ==##
##==Sub-routines:                                                   ==##
##==  code/2_normalization/ComputeWPEC.R                            ==##
##==  code/6_assessing_data/pcaArrayClinVar_subroutine.R            ==##
##==                                                                ==##
##==Figures for paper:                                              ==##
##==  *The percentage of variation explained                        ==##
##==  plots/forpaper/Supplementary_Figure7b.pdf                     ==##
##==                                                                ==##
##==Output:                                                         ==##
##==  *"data/Rdata/PCAarrayClinVar_",type1,"PCAcentered",no.comp,   ==##
##==  ".Rdata"                                                      ==##
##==  info, a data frame with columns corresponding to p-values,    ==##
##==  q-values, percentage of non-missingness and R2, for           ==##
##==  categorical-like variables it is the McFadden''s pseudo R2.   ==##
##==  The rows corresponding to the clinical variables.             ==##
##==  Provide information for Supplementary Table 2.                ==##
##==  *log/information_paper.log                                    ==##
##==  Information provided in the paper                             ==##
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu/            ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##


##==Assessing the variation in mean expression matrix
##Generate the mean expression matrix
txt.info<-"microarrayID250.168.batch"
min_hours<-12
max_hours<-250
constant<-10
#Summary method (0=LR Slope, 1=LR output intercept, 2=Mean value)
method<-2
source("code/2_normalization/ComputeWPEC.R",local=TRUE)
rm(list=ls())

txt.info<-"microarrayID250.168.batch"
min_hours<-12
max_hours<-250
method<-2
type1<-paste(txt.info," (",min_hours,"-",max_hours,").",method,sep="")
##Get the microarray data
load(file=paste("data/Rdata/microarray/",type1,".Rdata",sep=""))

##Filter the microarray data
##Remove the individuals due to quality reasons and death status
gDat<-gDat[,!(as.numeric(colnames(gDat))%in%c(8028773,25993337,33426107))]

##Centered
svd.obj<-svd(gDat-rowMeans(gDat))

##Plot the scree plot
pdf(paste("plots/forpaper/Supplementary_Figure7b.pdf",sep=""))
plot(svd.obj$d^2/sum(svd.obj$d^2),
xlab="Principal component index",
ylab="Proportion of variation explained")
dev.off()

##The number of components determined by scree plot
no.comp<-8
##Regress the clinical variables on the principal components:
source("code/6_assessing_data/pcaArrayClinVar_subroutine.R",local=TRUE)
save(info,file=paste("data/Rdata/PCAarrayClinVar_",type1,"PCAcentered",no.comp,".Rdata",sep=""))
	
##Print out information reported in the paper
##This not the first time sink is used (i.e. it is at "code/ocMOF/Getocmof.R",)
sink(file="log/information_paper.log",append=TRUE,split=TRUE)
print("=================================================================")
print("Information for supplementary material on PCA for mean expression")
print(paste("The total number of clinical variables:\n"))
print(ncol(clinDat)-1)
print(paste("The % of variation explained by ",no.comp," components with mean expression:\n"))
print(round((cumsum(svd.obj$d^2)/sum(svd.obj$d^2))[no.comp]*100))
print("The top 10 clinical variables")
print(info[1:10,])
print("The ranking of batch and trauma center")
print(info[info[,1]%in%c("batch","SITE_ACRONYM","ocMOF"),])
print("==================================================================")
sink(file=NULL)

pdf(file=paste("data/Rdata/PCAarrayClinVar_",type1,"PCAcentered.pdf",sep=""))
hist(p.valc,main=no.comp)
dev.off()
